@@ -3,6 +3,7 @@
 #' Evaluate a presence-absence table for each survey with '1' where there is data and '0' (printed as '.') otherwise.
 #'
 #' @param surveys a vector of survey names, or \code{NULL} to process all surveys.
+#' @param long whether tables should have year as row names (default) or column names.
 #'
 #' @return A list of tables.
 #'
@@ -12,14 +13,14 @@
 #'
 #' \code{\link{icesDatras-package}} gives an overview of the package.
 #'
-#' @author Colin Millar.
 #'
 #' @examples
-#' getDatrasDataOverview(surveys = "ROCKALL")
-#'
+#' \dontrun{
+#' getDatrasDataOverview(surveys = "ROCKALL", long = FALSE)
+#' }
 #' @export
 
-getDatrasDataOverview <- function(surveys = NULL) {
+getDatrasDataOverview <- function(surveys = NULL, long = TRUE) {
   # check web services are running
   if (!checkDatrasWebserviceOK()) return (FALSE)
 
@@ -32,10 +33,13 @@ getDatrasDataOverview <- function(surveys = NULL) {
              out <- sapply(as.character(getSurveyYearList(s)),
                            function(y) getSurveyYearQuarterList(s, as.integer(y)),
                            simplify = FALSE)
-             out <- t(sapply(out, function(x) as.integer(1:4 %in% x))) # hard wire 4 quarters
-             colnames(out) <- paste0("Q", 1:4)
-             class(out) <- "datrasoverview"
-             out
+             out <- sapply(out, function(x) as.integer(1:4 %in% x)) # hard wire 4 quarters
+             rownames(out) <- paste0("Q", 1:4)
+             class(out) <- c("datrasoverview", class(out))
+             if (long)
+               t(out)
+             else
+               out
            },
            simplify = FALSE)
 
